@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9671 2016-05-25 10:13:34Z Eric $
+# $Id: __init__.py 9734 2017-02-05 14:48:10Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -11,9 +11,9 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-# $Author: Eric $ (last)
-# $Date: 2016-05-25 18:13:34 +0800 (週三, 25 五月 2016) $
-# $Revision: 9671 $
+# $Author: David $ (last)
+# $Date: 2017-02-05 22:48:10 +0800 (Sun, 05 Feb 2017) $
+# $Revision: 9734 $
 
 import os
 import sys
@@ -696,6 +696,30 @@ def attachSettings(settingsDict):
     else: # IUNO_MEMBER_ENABLE = False
         warnPackageDisable('Iuno.member', settingsDict, iunoMemberDefaults)
     #=========================================================================
+
+    #=========================================================================
+    #  Iuno.shop.
+    checkImportPackage('Iuno.shop', settingsDict)
+    import Iuno.shop
+    
+    iunoShopDefaults = {
+        'IUNO_SHOP_ENABLE': False,
+        'IUNO_SHOP_PAYPAL_ENABLE': False,
+    }
+
+    update(settingsDict, iunoShopDefaults)
+    
+    populateEnvToSettings(iunoShopDefaults.keys(), settingsDict, 
+                          evalKeys=iunoShopDefaults.keys())
+
+    if settingsDict['IUNO_SHOP_ENABLE']:
+        Iuno.shop.attachSettings(
+                        settingsDict,
+                        settingsDict['IUNO_SHOP_PAYPAL_ENABLE'],
+                    )
+    else: # IUNO_SHOP_ENABLE = False
+        warnPackageDisable('Iuno.shop', settingsDict, iunoShopDefaults)
+    #=========================================================================
     
     #=========================================================================
     # Patch.
