@@ -49,7 +49,6 @@ def attachSettings(settingsDict, enablePaypal=False):
         'django.contrib.flatpages',
         'compressor',
         'widget_tweaks',
-        'paypal',
     ) + tuple(get_core_apps())
     
     ADDING_MIDDLEWARE_CLASSES = (
@@ -128,8 +127,47 @@ def attachSettings(settingsDict, enablePaypal=False):
     update(settingsDict, ADDING_HAYSTACK_CONNECTIONS)
     #=========================================================================
     # Oscar default currency
-    OSCAR_DEFAULT_CURRENCY = 'USD'
+    ADDING_OSCAR_DEFAULT_CURRENCY = {
+        'OSCAR_DEFAULT_CURRENCY' : 'USD'
+    }
+    update(settingsDict, ADDING_OSCAR_DEFAULT_CURRENCY)
+
+    # Site id
+    ADDING_SITE_ID = {
+        'SITE_ID' : 1
+    }
+    update(settingsDict, ADDING_SITE_ID)
     #=========================================================================
     if enablePaypal:
-        pass
+        require('PAYPAL_API_USERNAME', settingsDict)
+        require('PAYPAL_API_PASSWORD', settingsDict)
+        require('PAYPAL_API_SIGNATURE', settingsDict)
+
+        ADDING_PAYPAL_INSTALLED_APPS = (
+            'paypal',
+        )
+        extendInstalledApps(settingsDict, ADDING_PAYPAL_INSTALLED_APPS,
+                        key=list(keys)[-1])
+
+
+        ADDING_OSCAR_SHOP_TAGLINE = {
+            'OSCAR_SHOP_TAGLINE' : 'Paypal'
+        }
+        update(settingsDict, ADDING_OSCAR_SHOP_TAGLINE)
+
+        ADDING_OSCAR_DASHBOARD_NAVIGATION = {
+            'label': _('PayPal'),
+            'icon': 'icon-globe',
+            'children': [
+                {
+                    'label': _('Express transactions'),
+                    'url_name': 'paypal-express-list',
+                },
+            ]
+        }
+        if 'OSCAR_DASHBOARD_NAVIGATION' in settingsDict:
+            settingsDict['OSCAR_DASHBOARD_NAVIGATION'].append(ADDING_OSCAR_DASHBOARD_NAVIGATION)
+        else:
+            settingsDict['OSCAR_DASHBOARD_NAVIGATION'] = ADDING_OSCAR_DASHBOARD_NAVIGATION
+    #=========================================================================
 
